@@ -1,5 +1,4 @@
-`CalmarRatio` <-
-function (R, scale = NA)
+CalmarRatio <- function (R, scale = NA)
 { # @author Brian G. Peterson
 
     # DESCRIPTION:
@@ -32,7 +31,7 @@ function (R, scale = NA)
     return(result)
 }
 
-`SterlingRatio` <-
+SterlingRatio <-
 function (R, scale=NA, excess=.1)
 { # @author Brian G. Peterson
 
@@ -71,40 +70,9 @@ function (R, scale=NA, excess=.1)
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: CalmarRatio.R 1503 2010-01-02 11:48:32Z braverock $
-#
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.8  2009-10-06 15:14:44  peter
-# - fixed rownames
-# - fixed scale = 12 replacement errors
-#
-# Revision 1.7  2009-10-06 03:00:31  peter
-# - added label to results
-#
-# Revision 1.6  2009-10-03 18:23:55  brian
-# - multiple Code-Doc mismatches cleaned up for R CMD check
-# - further rationalized use of R,Ra,Rf
-# - rationalized use of period/scale
-#
-# Revision 1.5  2009-10-01 01:53:07  peter
-# - missed one
-#
-# Revision 1.4  2009-10-01 01:52:13  peter
-# - changed Ra to R for consistency
-#
-# Revision 1.3  2009-10-01 01:45:17  peter
-# - added multi-column support
-# - added periodicity check for scale
-#
-# Revision 1.2  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.1  2007/06/23 12:06:08  brian
-# - initial revision of Calmar and Sterling Ratio functions and docs
-#   originally requested by Khanh Nguyen <chaokhanh@yahoo.com>
+# $Id: CalmarRatio.R 1730 2010-08-03 19:31:06Z braverock $
 #
 ###############################################################################
\ No newline at end of file
