@@ -1,4 +1,4 @@
-`SmoothingIndex` <-
+SmoothingIndex <-
 function (R, neg.thetas = FALSE, MAorder=2, verbose = FALSE, ...)
 { # @author Peter Carl
 
@@ -89,4 +89,16 @@ function (R, neg.thetas = FALSE, MAorder=2, verbose = FALSE, ...)
             return(result)
         }
     }
-}
\ No newline at end of file
+}
+
+###############################################################################
+# R (http://r-project.org/) Econometrics for Performance and Risk Analysis
+#
+# Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
+#
+# This R package is distributed under the terms of the GNU Public License (GPL)
+# for full details see the file COPYING
+#
+# $Id: SmoothingIndex.R 1730 2010-08-03 19:31:06Z braverock $
+#
+###############################################################################
\ No newline at end of file
