@@ -1,4 +1,4 @@
-`chart.Drawdown` <-
+chart.Drawdown <-
 function (R, geometric = TRUE, legend.loc = NULL, colorset = (1:12), ...)
 { # @author Peter Carl
 
@@ -27,6 +27,13 @@ function (R, geometric = TRUE, legend.loc = NULL, colorset = (1:12), ...)
     # Calculate drawdown level
     drawdown = Drawdowns(R, geometric)
 
+    # workaround provided by Samuel Le to handle single-column input
+    if(NCOL(R)==1)
+    {
+        drawdown<-as.xts(drawdown)
+        colnames(drawdown)<-colnames(R)
+    }
+    
     # Chart the drawdown level
     chart.TimeSeries(drawdown, col = colorset, legend.loc = legend.loc, ...)
 
@@ -37,38 +44,9 @@ function (R, geometric = TRUE, legend.loc = NULL, colorset = (1:12), ...)
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.Drawdown.R 1510 2010-01-04 03:41:19Z peter_carl $
-#
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.8  2009-08-31 20:51:27  brian
-# - add new function na.skip to deal with non-contiguous NA's in data, may eventually go to xts
-# - fix components of charts.PerformanceSummary to use na.skip
-#
-# Revision 1.7  2009-03-20 03:22:53  peter
-# - added xts
-#
-# Revision 1.6  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.5  2007/03/13 03:57:37  peter
-# - uses checkData function
-#
-# Revision 1.4  2007/03/10 19:46:35  peter
-# - handles unequal periods
-# - correctly calculates when first period is negative
-#
-# Revision 1.3  2007/02/26 13:50:57  brian
-# - change cumMax.column to cummax.column to reflect change in function name to pass "R CMD check"
-#
-# Revision 1.2  2007/02/07 13:24:49  brian
-# - fix pervasive comment typo
-#
-# Revision 1.1  2007/02/02 19:06:15  brian
-# - Initial Revision of packaged files to version control
-# Bug 890
+# $Id: chart.Drawdown.R 1730 2010-08-03 19:31:06Z braverock $
 #
 ###############################################################################
\ No newline at end of file
