@@ -1,4 +1,4 @@
-`chart.ECDF` <-
+chart.ECDF <-
 function(R, main = "Empirical CDF", xlab="x", ylab="F(x)", colorset = c("black", "#005AFF"), lwd = 1, xlim = NULL, ylim = NULL, lty = c(1,1), element.color = "darkgray", ...)
 { # @author Peter Carl
 
@@ -36,18 +36,9 @@ function(R, main = "Empirical CDF", xlab="x", ylab="F(x)", colorset = c("black",
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.ECDF.R 1503 2010-01-02 11:48:32Z braverock $
-#
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.3  2009-04-07 22:19:46  peter
-# - changed to use element.color parameter
-#
-# Revision 1.2  2008-06-25 03:48:00  peter
-# - added copyright and CVS log
-#
+# $Id: chart.ECDF.R 1730 2010-08-03 19:31:06Z braverock $
 #
 ###############################################################################
\ No newline at end of file
