@@ -1,4 +1,4 @@
-`chart.Events` <-
+chart.Events <-
 function (R, dates, prior=12, post=12, main = NULL, xlab=NULL, ...)
 { # @author Peter Carl
   R = checkData(R[,1,drop=FALSE]) 
@@ -49,10 +49,9 @@ function (R, dates, prior=12, post=12, main = NULL, xlab=NULL, ...)
 #
 # Copyright (c) 2004-2007 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.Events.R 1408 2009-11-09 13:57:00Z braverock $
+# $Id: chart.Events.R 1730 2010-08-03 19:31:06Z braverock $
 #
-###############################################################################
-# $Log: not supported by cvs2svn $
+###############################################################################
\ No newline at end of file
