@@ -1,4 +1,4 @@
-`charts.PerformanceSummary` <-
+charts.PerformanceSummary <-
 function (R, Rf = 0, main = NULL, geometric=TRUE, methods = "none", width = 0, event.labels = NULL, ylog = FALSE, wealth.index = FALSE, gap = 12, begin=c("first","axis"), legend.loc="topleft", p=0.95,...)
 { # @author Peter Carl
 
@@ -101,79 +101,9 @@ function (R, Rf = 0, main = NULL, geometric=TRUE, methods = "none", width = 0, e
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: charts.PerformanceSummary.R 1637 2010-03-16 02:32:08Z peter_carl $
+# $Id: charts.PerformanceSummary.R 1730 2010-08-03 19:31:06Z braverock $
 #
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.21  2009-10-03 18:23:55  brian
-# - multiple Code-Doc mismatches cleaned up for R CMD check
-# - further rationalized use of R,Ra,Rf
-# - rationalized use of period/scale
-#
-# Revision 1.20  2009-08-31 16:35:48  brian
-# - add periodicity to label of chart.BarVaR
-#
-# Revision 1.19  2009-03-20 03:22:53  peter
-# - added xts
-#
-# Revision 1.18  2008-08-16 03:38:54  peter
-# - changed chart.BarVaR call from 'method' to 'methods'
-#
-# Revision 1.17  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.16  2008-04-18 03:51:44  peter
-# - added par to reset graphics layout to default
-#
-# Revision 1.15  2007/09/24 02:50:28  peter
-# - cleaned up spacing in title
-#
-# Revision 1.14  2007/08/23 02:12:04  peter
-# - added legend.loc as parameter so that legend can be shut off or moved
-# in top chart
-#
-# Revision 1.13  2007/08/15 00:04:44  peter
-# - aligns the three charts along the start date of the first column of
-# data
-#
-# Revision 1.12  2007/06/29 15:52:25  peter
-# - removed plot.new() that was causing two page pdf files
-#
-# Revision 1.11  2007/06/18 03:35:22  brian
-# - make method argument a list
-#
-# Revision 1.10  2007/04/30 12:56:05  peter
-# - changed 'method' to 'begin'
-#
-# Revision 1.9  2007/04/09 12:31:27  brian
-# - syntax and usage changes to pass R CMD check
-#
-# Revision 1.8  2007/04/04 02:46:34  peter
-# - added gap parameter for chart.BarVaR
-#
-# Revision 1.7  2007/03/22 13:48:11  peter
-# - removed yaxis label in favor of default
-#
-# Revision 1.6  2007/03/21 21:46:54  peter
-# - passing in wealth.index to top chart
-#
-# Revision 1.5  2007/03/21 21:44:21  peter
-# - fixed conditional test
-#
-# Revision 1.4  2007/03/21 21:40:48  peter
-# - added error handling for ylog passing in top chart
-#
-# Revision 1.3  2007/03/20 13:48:07  peter
-# - changed "n" attribute to "width" in chart.BarVaR call
-#
-# Revision 1.2  2007/02/07 13:24:49  brian
-# - fix pervasive comment typo
-#
-# Revision 1.1  2007/02/02 19:06:15  brian
-# - Initial Revision of packaged files to version control
-# Bug 890
-#
-###############################################################################
+###############################################################################
\ No newline at end of file
