@@ -1,4 +1,4 @@
-`sortDrawdowns` <-
+sortDrawdowns <-
 function (runs) {
     # sortDrawdowns(findDrawdowns(caduceus.ts@Data[,1]))
     # gives the drawdowns in order of worst to best
@@ -43,27 +43,9 @@ function (runs) {
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: sortDrawdowns.R 1503 2010-01-02 11:48:32Z braverock $
-#
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.5  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.4  2007/03/21 14:08:15  peter
-# - added sorts on new attributes in findDrawdowns.R
-#
-# Revision 1.3  2007/02/07 13:24:49  brian
-# - fix pervasive comment typo
-#
-# Revision 1.2  2007/02/06 11:58:42  brian
-# - standardize attribution for Drawdown runs
-#
-# Revision 1.1  2007/02/02 19:06:15  brian
-# - Initial Revision of packaged files to version control
-# Bug 890
+# $Id: sortDrawdowns.R 1730 2010-08-03 19:31:06Z braverock $
 #
 ###############################################################################
\ No newline at end of file
