@@ -1,4 +1,4 @@
-`table.Arbitrary` <-
+table.Arbitrary <-
 function (R, metrics=c("mean","sd"), metricsNames=c("Average Return","Standard Deviation"), ...)
 { # @author Peter Carl
 
@@ -81,7 +81,7 @@ function (R, metrics=c("mean","sd"), metricsNames=c("Average Return","Standard D
 }
 ###############################################################################
 
-`statsTable` <-
+statsTable <-
 function(R, metrics=c("mean","sd"), metricsNames=c("Average Return","Standard Deviation"), ...)
 {   # @author Peter Carl
 
@@ -99,35 +99,9 @@ function(R, metrics=c("mean","sd"), metricsNames=c("Average Return","Standard De
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: table.Arbitrary.R 1503 2010-01-02 11:48:32Z braverock $
-#
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.8  2009-10-03 18:23:55  brian
-# - multiple Code-Doc mismatches cleaned up for R CMD check
-# - further rationalized use of R,Ra,Rf
-# - rationalized use of period/scale
-#
-# Revision 1.7  2008-10-14 14:37:29  brian
-# - convert from matrix or data.frame to zoo in checkData call
-#
-# Revision 1.6  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.5  2007/12/27 20:59:35  peter
-# - cleaned out commented lines
-#
-# Revision 1.3  2007/12/27 20:46:47  peter
-# - fixed bug to calculate number of columns
-#
-# Revision 1.2  2007/02/07 13:24:49  brian
-# - fix pervasive comment typo
-#
-# Revision 1.1  2007/02/02 19:06:15  brian
-# - Initial Revision of packaged files to version control
-# Bug 890
+# $Id: table.Arbitrary.R 1730 2010-08-03 19:31:06Z braverock $
 #
 ###############################################################################
\ No newline at end of file
