@@ -1,4 +1,4 @@
-`table.CaptureRatios` <-
+table.CaptureRatios <-
 function (Ra, Rb, digits = 4)
 {# @author Peter Carl
 
@@ -41,21 +41,9 @@ function (Ra, Rb, digits = 4)
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: table.CaptureRatios.R 1503 2010-01-02 11:48:32Z braverock $
+# $Id: table.CaptureRatios.R 1730 2010-08-03 19:31:06Z braverock $
 #
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.4  2009-10-06 18:31:25  peter
-# - updated method tags
-#
-# Revision 1.3  2009-04-17 04:10:23  peter
-# - parameter cleanup
-#
-# Revision 1.2  2009-04-02 03:06:37  peter
-# - added CVS log
-#
-# 
 ###############################################################################
\ No newline at end of file
